@@ -8,7 +8,7 @@
 #
 package IO::Socket::Timeout;
 {
-  $IO::Socket::Timeout::VERSION = '0.13';
+  $IO::Socket::Timeout::VERSION = '0.14';
 }
 
 use strict;
@@ -122,7 +122,7 @@ IO::Socket::Timeout - IO::Socket with read/write timeout
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -168,7 +168,7 @@ This module provides a way to set a timeout on read / write operations on an
 C<IO::Socket> instance, or any C<IO::Socket::*> modules, like
 C<IO::Socket::INET>.
 
-=head1 CONSTRUCTOR
+=head1 CONSTRUCTORS
 
 =head2 new::with::timeout
 
@@ -219,6 +219,40 @@ To get a list of available strategy, see below (L<AVAILABLE STRATEGIES>).
 
 =back
 
+=head2 socketpair::with::timeout
+
+There is an other way to create sockets from scratch, via C<socketpair>. As for
+the C<new> constructor, this module provides its counterpart with timeout
+feature.
+
+C<IO::Socket::INET->socketpair::with::timeout(...)> will return two instances of
+C<IO::Socket::INET>, as if it had been called with
+C<IO::Socket::INET->socketpair(...)>. However, it'll apply some mechanism on the
+resulting socket object so that it times out on read, write, or both.
+
+=head1 FINE-TUNING
+
+If you need to alter the behavior of the socket after it has been created, you
+can access its strategy and fiddle with it, using PerlIO::via::Timeout.
+
+  use IO::Socket::With::Timeout;
+  # create a socket with read timeout
+  my $socket = IO::Socket::INET->new::with::timeout( Timeout => 2,
+                                                     ReadTimeout => 0.5,
+                                                     # other standard arguments );
+  use PerlIO::via::Timeout qw(timeout_strategy);
+  # use PerlIO::via::Timeout to retrieve the strategy
+  my stratefy = timeout_strategy($sock);
+  # change read_timeout to 5 and write timeout to 1.5 sec
+  $strategy->read_timeout(5)
+  $strategy->write_timeout(1.5)
+  # actually disable the timeout for now
+  $strategy->disable_timeout()
+  # when re-enabling it, timeouts value are restored
+  $strategy->enable_timeout()
+
+See L<PerlIO::via::Timeout> for more details
+
 =head1 WHEN TIMEOUT IS HIT
 
 When a timeout (read, write) is hit on the socket, the function trying to be
